==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/SASAuthTypeWorkspaceConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ConnectionCategory
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ValueFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property authType Authentication type of the connection target
 * Expected value is 'SAS'.
 * @property category Category of the connection
 * @property credentials
 * @property target
 * @property value Value details of the workspace connection.
 * @property valueFormat format for the workspace connection value
 */
public data class SASAuthTypeWorkspaceConnectionPropertiesArgs(
    public val authType: Output<String>,
    public val category: Output<Either<String, ConnectionCategory>>? = null,
    public val credentials: Output<WorkspaceConnectionSharedAccessSignatureArgs>? = null,
    public val target: Output<String>? = null,
    public val `value`: Output<String>? = null,
    public val valueFormat: Output<Either<String, ValueFormat>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .category(
                category?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .credentials(credentials?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 }))
            .valueFormat(
                valueFormat?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SASAuthTypeWorkspaceConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class SASAuthTypeWorkspaceConnectionPropertiesArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var category: Output<Either<String, ConnectionCategory>>? = null

    private var credentials: Output<WorkspaceConnectionSharedAccessSignatureArgs>? = null

    private var target: Output<String>? = null

    private var `value`: Output<String>? = null

    private var valueFormat: Output<Either<String, ValueFormat>>? = null

    /**
     * @param value Authentication type of the connection target
     * Expected value is 'SAS'.
     */
    @JvmName("ofwxtfbjduudtcns")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("mqdhxnftipsfpqse")
    public suspend fun category(`value`: Output<Either<String, ConnectionCategory>>) {
        this.category = value
    }

    /**
     * @param value
     */
    @JvmName("ktmwjujidvjnvtie")
    public suspend fun credentials(`value`: Output<WorkspaceConnectionSharedAccessSignatureArgs>) {
        this.credentials = value
    }

    /**
     * @param value
     */
    @JvmName("lawveyowjywvviih")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Value details of the workspace connection.
     */
    @JvmName("kovunotqphhyjddk")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("bdgwolrmiixblidg")
    public suspend fun valueFormat(`value`: Output<Either<String, ValueFormat>>) {
        this.valueFormat = value
    }

    /**
     * @param value Authentication type of the connection target
     * Expected value is 'SAS'.
     */
    @JvmName("exadpotvdwhkfcan")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("rararjwafkdnjtni")
    public suspend fun category(`value`: Either<String, ConnectionCategory>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("ufqvheoxjxpcbisr")
    public fun category(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionCategory>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("qicnmfhhyryoejhr")
    public fun category(`value`: ConnectionCategory) {
        val toBeMapped = Either.ofRight<String, ConnectionCategory>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value
     */
    @JvmName("fouohosbhgivobrw")
    public suspend fun credentials(`value`: WorkspaceConnectionSharedAccessSignatureArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credentials = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tmwmvyufxaehctwb")
    public suspend
    fun credentials(argument: suspend WorkspaceConnectionSharedAccessSignatureArgsBuilder.() -> Unit) {
        val toBeMapped = WorkspaceConnectionSharedAccessSignatureArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.credentials = mapped
    }

    /**
     * @param value
     */
    @JvmName("ofhsmmyvuixdujrv")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param value Value details of the workspace connection.
     */
    @JvmName("mpsjvcdfdxaaecud")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("bsndndgyngweccpd")
    public suspend fun valueFormat(`value`: Either<String, ValueFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("ycenngbgawituobw")
    public fun valueFormat(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ValueFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("bylcdscjuhxxiwwp")
    public fun valueFormat(`value`: ValueFormat) {
        val toBeMapped = Either.ofRight<String, ValueFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    internal fun build(): SASAuthTypeWorkspaceConnectionPropertiesArgs =
        SASAuthTypeWorkspaceConnectionPropertiesArgs(
            authType = authType ?: throw PulumiNullFieldException("authType"),
            category = category,
            credentials = credentials,
            target = target,
            `value` = `value`,
            valueFormat = valueFormat,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/SASAuthTypeWorkspaceConnectionPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ConnectionCategory
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ValueFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property authType Authentication type of the connection target
 * Expected value is 'SAS'.
 * @property category Category of the connection
 * @property credentials
 * @property target
 * @property value Value details of the workspace connection.
 * @property valueFormat format for the workspace connection value
 */
public data class SASAuthTypeWorkspaceConnectionPropertiesArgs(
    public val authType: Output<String>,
    public val category: Output<Either<String, ConnectionCategory>>? = null,
    public val credentials: Output<WorkspaceConnectionSharedAccessSignatureArgs>? = null,
    public val target: Output<String>? = null,
    public val `value`: Output<String>? = null,
    public val valueFormat: Output<Either<String, ValueFormat>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.SASAuthTypeWorkspaceConnectionPropertiesArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .category(
                category?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .credentials(credentials?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 }))
            .valueFormat(
                valueFormat?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SASAuthTypeWorkspaceConnectionPropertiesArgs].
 */
@PulumiTagMarker
public class SASAuthTypeWorkspaceConnectionPropertiesArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var category: Output<Either<String, ConnectionCategory>>? = null

    private var credentials: Output<WorkspaceConnectionSharedAccessSignatureArgs>? = null

    private var target: Output<String>? = null

    private var `value`: Output<String>? = null

    private var valueFormat: Output<Either<String, ValueFormat>>? = null

    /**
     * @param value Authentication type of the connection target
     * Expected value is 'SAS'.
     */
    @JvmName("ahxjbqmftogtbchc")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("oaheajrcaaqedrgr")
    public suspend fun category(`value`: Output<Either<String, ConnectionCategory>>) {
        this.category = value
    }

    /**
     * @param value
     */
    @JvmName("tggounvbkmbcuunr")
    public suspend fun credentials(`value`: Output<WorkspaceConnectionSharedAccessSignatureArgs>) {
        this.credentials = value
    }

    /**
     * @param value
     */
    @JvmName("txfbfdxdawnmlcwq")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Value details of the workspace connection.
     */
    @JvmName("thwppegkbvvxwcsw")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("vohqthlaodqryojc")
    public suspend fun valueFormat(`value`: Output<Either<String, ValueFormat>>) {
        this.valueFormat = value
    }

    /**
     * @param value Authentication type of the connection target
     * Expected value is 'SAS'.
     */
    @JvmName("oybckotkwbjkdkky")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("wrdimmuwtwfavhqg")
    public suspend fun category(`value`: Either<String, ConnectionCategory>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("qmkmwykuofhkrefe")
    public fun category(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionCategory>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value Category of the connection
     */
    @JvmName("nsavgwfdeuhxlovg")
    public fun category(`value`: ConnectionCategory) {
        val toBeMapped = Either.ofRight<String, ConnectionCategory>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.category = mapped
    }

    /**
     * @param value
     */
    @JvmName("baldphnpwnfcitdq")
    public suspend fun credentials(`value`: WorkspaceConnectionSharedAccessSignatureArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credentials = mapped
    }

    /**
     * @param argument
     */
    @JvmName("shsgvghiwpryrbwm")
    public suspend
    fun credentials(argument: suspend WorkspaceConnectionSharedAccessSignatureArgsBuilder.() -> Unit) {
        val toBeMapped = WorkspaceConnectionSharedAccessSignatureArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.credentials = mapped
    }

    /**
     * @param value
     */
    @JvmName("dfkkuudcaonkgpjm")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param value Value details of the workspace connection.
     */
    @JvmName("fubhcvbdbsjwibvy")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("skgkqpphrgeqyovt")
    public suspend fun valueFormat(`value`: Either<String, ValueFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("qkmecoclsvpjnxor")
    public fun valueFormat(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ValueFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    /**
     * @param value format for the workspace connection value
     */
    @JvmName("hsqnwrncvhvhmbkn")
    public fun valueFormat(`value`: ValueFormat) {
        val toBeMapped = Either.ofRight<String, ValueFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.valueFormat = mapped
    }

    internal fun build(): SASAuthTypeWorkspaceConnectionPropertiesArgs =
        SASAuthTypeWorkspaceConnectionPropertiesArgs(
            authType = authType ?: throw PulumiNullFieldException("authType"),
            category = category,
            credentials = credentials,
            target = target,
            `value` = `value`,
            valueFormat = valueFormat,
        )
}
